<?php
/**
 * @file
 * Gamertag Plugin: Provides Nintendo Mario Kart Gamertags.
 */

class gamertags_mariokart extends gamertags {
  /**
   * Return information about this platform.
   *
   * @return
   *   #machine_name: Machine-name of this platform, should match the class name; "xbox" for "gamertags_xbox"
   *   #title: Human-readable title for administrative displays
   *   #description: (optional) Human-readable description for administrative displays
   */
  static public function getInfo() {
    return array(
      '#machine_name' => 'mariokart',
      '#title' => t('Mario Kart Gamertags'),
      '#description' => t('Nintendo Mario Kart Friend Code'),
    );
  }

  /**
   * Return filter information about this platform.
   *
   * @return
   *   short: Human-readable short description for filter tips
   *   long: Human-readable long description for filter tips
   */
  static public function filterInfo() {
    return array(
      'short' => '[mariokart:id]',
      'long' => t('Nintendo Mario Kart Gamertag by typing [mariokart:id]'),
    );
  }

  /**
   * Return token information about this platform.
   *
   * @return
   *   array containing token information where the key is a machine-name and the value
   *   a description of the token output
   */
  static public function tokenList() {
    return array(
      'user-gamertag-mariokart' => t('Corresponding Nintendo Mario Kart Gamertag for this user.'),
      'user-gamertag-mariokart-text' => t('Corresponding Nintendo Mario Kart Gamertag for this user (as plain text).'),
    );
  }

  /**
   * Return token values for this platform.
   *
   * @return
   *   array containing token values where the key is a machine-name and the value
   *   contains themed gamertag output
   */
  static public function tokenValues(stdClass $account) {
    return array(
      'user-gamertag-mariokart' => self::render($account, __CLASS__),
      'user-gamertag-mariokart-text' => check_plain($account->gamertags_mariokart),
    );
  }

  /**
   * Extends hook_user_view().
   */
  public function userView(stdClass &$account) {
    $account->content['summary']['gamertags_mariokart_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Mario Kart Friend Code'),
      '#value' => self::render($account, __CLASS__),
      '#weight' => (int) variable_get('gamertags_mariokart_weight', 0),
    );
  }

  /**
   * Extends hook_user_form().
   */
  public function userForm(stdClass $account) {
    return array(
      'gamertags_mariokart' => array(
        '#type' => 'textfield',
        '#title' => t('Nintendo Mario Kart'),
        '#default_value' => isset($account->gamertags_mariokart) ? $account->gamertags_mariokart : '',
        '#description' => t('If you have one, please enter your Mario Kart Friend Code.'),
        '#weight' => (int) variable_get('gamertags_mariokart_weight', 0),
      ),
    );
  }

  /**
   * Validation for userForm().
   */
  function userFormValidate(&$values) {
    if (($mariokart_gamertag = preg_replace(array("/\s+/", "/-+/"), "", $values['gamertags_mariokart'])) && (!preg_match("/^[0-9]+$/", $mariokart_gamertag) || drupal_strlen($mariokart_gamertag) != 12)) {
      form_set_error('gamertags_mariokart', t('Mario Kart Friend Codes can be 12 digit numbers only.'));
    }
    // For fun, let's format all Mario Kart friendcodes so they look like this 1234-1234-1234.
    if (!empty($mariokart_gamertag)) {
      $values['gamertags_mariokart'] = preg_replace("/([0-9]{4})([0-9]{4})([0-9]{4})/", "$1-$2-$3", $mariokart_gamertag);
    }
  }

  public function adminUrlSettings() { return array(); }

  /**
   * Extends hook_theme().
   */
  public function theme() {
    return array(
      'arguments' => array(
        'gamertag' => NULL,
      ),
      'template' => 'platforms/nintendo/mariokart/gamertags.mariokart',
      'file' => 'platforms/nintendo/mariokart/gamertags.mariokart.inc',
    );
  }

  /**
   * Provides values for SimpleTest.
   */
  public function _testContent(&$edit, $calling_class) {
    $edit['gamertags_mariokart'] = '111111111111';
  }
}

/**
 * Preprocess function for gamertags_mariokart theme function.
 */
function gamertags_preprocess_gamertags_mariokart(&$variables) {
  $variables['gamertag'] = check_plain($variables['gamertag']);
}
