<?php
/**
 * @file
 * Gamertag Plugin: Provides Nintendo Mario Kart 7 Gamertags.
 */

class gamertags_mariokart7 extends gamertags {
  /**
   * Return information about this platform.
   *
   * @return
   *   #machine_name: Machine-name of this platform, should match the class name; "xbox" for "gamertags_xbox"
   *   #title: Human-readable title for administrative displays
   *   #description: (optional) Human-readable description for administrative displays
   */
  static public function getInfo() {
    return array(
      '#machine_name' => 'mariokart7',
      '#title' => t('Mario Kart 7 Gamertags'),
      '#description' => t('Nintendo Mario Kart 7 Friend Code'),
    );
  }

  /**
   * Return filter information about this platform.
   *
   * @return
   *   short: Human-readable short description for filter tips
   *   long: Human-readable long description for filter tips
   */
  static public function filterInfo() {
    return array(
      'short' => '[mariokart7:id]',
      'long' => t('Nintendo Mario Kart 7 Gamertag by typing [mariokart7:id]'),
    );
  }

  /**
   * Return token information about this platform.
   *
   * @return
   *   array containing token information where the key is a machine-name and the value
   *   a description of the token output
   */
  static public function tokenList() {
    return array(
      'user-gamertag-mariokart7' => t('Corresponding Nintendo Mario Kart 7 Gamertag for this user.'),
      'user-gamertag-mariokart7-text' => t('Corresponding Nintendo Mario Kart 7 Gamertag for this user (as plain text).'),
    );
  }

  /**
   * Return token values for this platform.
   *
   * @return
   *   array containing token values where the key is a machine-name and the value
   *   contains themed gamertag output
   */
  static public function tokenValues(stdClass $account) {
    return array(
      'user-gamertag-mariokart7' => self::render($account, __CLASS__),
      'user-gamertag-mariokart7-text' => check_plain($account->gamertags_mariokart7),
    );
  }

  /**
   * Extends hook_user_view().
   */
  public function userView(stdClass &$account) {
    $account->content['summary']['gamertags_mariokart7_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Mario Kart 7 Friend Code'),
      '#value' => self::render($account, __CLASS__),
      '#weight' => (int) variable_get('gamertags_mariokart7_weight', 0),
    );
  }

  /**
   * Extends hook_user_form().
   */
  public function userForm(stdClass $account) {
    return array(
      'gamertags_mariokart7' => array(
        '#type' => 'textfield',
        '#title' => t('Nintendo Mario Kart 7'),
        '#default_value' => isset($account->gamertags_mariokart7) ? $account->gamertags_mariokart7 : '',
        '#description' => t('If you have one, please enter your Mario Kart 7 Friend Code.'),
        '#weight' => (int) variable_get('gamertags_mariokart7_weight', 0),
      ),
    );
  }

  /**
   * Validation for userForm().
   */
  function userFormValidate(&$values) {
    if (($mariokart7_gamertag = preg_replace(array("/\s+/", "/-+/"), "", $values['gamertags_mariokart7'])) && (!preg_match("/^[0-9]+$/", $mariokart7_gamertag) || drupal_strlen($mariokart7_gamertag) != 12)) {
      form_set_error('gamertags_mariokart7', t('Mario Kart 7 Friend Codes can be 12 digit numbers only.'));
    }
    // For fun, let's format all Mario Kart 7 friendcodes so they look like this 1234-1234-1234.
    if (!empty($mariokart7_gamertag)) {
      $values['gamertags_mariokart7'] = preg_replace("/([0-9]{4})([0-9]{4})([0-9]{4})/", "$1-$2-$3", $mariokart7_gamertag);
    }
  }

  public function adminUrlSettings() { return array(); }

  /**
   * Extends hook_theme().
   */
  public function theme() {
    return array(
      'arguments' => array(
        'gamertag' => NULL,
      ),
      'template' => 'platforms/nintendo/mariokart7/gamertags.mariokart7',
      'file' => 'platforms/nintendo/mariokart7/gamertags.mariokart7.inc',
    );
  }

  /**
   * Provides values for SimpleTest.
   */
  public function _testContent(&$edit, $calling_class) {
    $edit['gamertags_mariokart7'] = '111111111111';
  }
}

/**
 * Preprocess function for gamertags_mariokart theme function.
 */
function gamertags_preprocess_gamertags_mariokart7(&$variables) {
  drupal_add_css(drupal_get_path('module', 'gamertags') .'/platforms/nintendo/mariokart7/gamertags.mariokart7.css');
  $variables['gamertag'] = check_plain($variables['gamertag']);
}
