<?php
/**
 * @file
 * Gamertag Plugin: Provides Nintendo Network ID Gamertags.
 */

class gamertags_nintendo_network_id extends gamertags {
  /**
   * Return information about this platform.
   *
   * @return
   *   #machine_name: Machine-name of this platform, should match the class name; "xbox" for "gamertags_xbox"
   *   #title: Human-readable title for administrative displays
   *   #description: (optional) Human-readable description for administrative displays
   */
  static public function getInfo() {
    return array(
      '#machine_name' => 'nintendo_network_id',
      '#title' => t('Nintendo Network ID'),
      '#description' => t('Nintendo Network ID Gamertags'),
    );
  }

  /**
   * Return filter information about this platform.
   *
   * @return
   *   short: Human-readable short description for filter tips
   *   long: Human-readable long description for filter tips
   */
  static public function filterInfo() {
    return array(
      'short' => '[nintendo_network_id:id]',
      'long' => t('Nintendo Network ID Gamertag by typing [nintendo_network_id:id]'),
    );
  }

  /**
   * Return token information about this platform.
   *
   * @return
   *   array containing token information where the key is a machine-name and the value
   *   a description of the token output
   */
  static public function tokenList() {
    return array(
      'user-gamertag-nintendo-network-id' => t('Corresponding Nintendo Network ID for this user.'),
      'user-gamertag-nintendo-network-id-text' => t('Corresponding Nintendo Network ID for this user (as plain text).'),
    );
  }

  /**
   * Return token values for this platform.
   *
   * @return
   *   array containing token values where the key is a machine-name and the value
   *   contains themed gamertag output
   */
  static public function tokenValues(stdClass $account) {
    return array(
      'user-gamertag-nintendo-network-id' => self::render($account, __CLASS__),
      'user-gamertag-nintendo-network-id-text' => check_plain($account->gamertags_nintendo_network_id),
    );
  }

  /**
   * Extends hook_user_view().
   */
  function userView(stdClass &$account) {
    $account->content['summary']['gamertags_nintendo_network_id_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Nintendo Network ID'),
      '#value' => self::render($account, __CLASS__),
      '#weight' => (int) variable_get('gamertags_nintendo_network_id_weight', 0),
    );
  }

  /**
   * Extends hook_user_form().
   */
  function userForm(stdClass $account) {
    return array(
      'gamertags_nintendo_network_id' => array(
        '#type' => 'textfield',
        '#title' => t('Nintendo Network ID'),
        '#default_value' => isset($account->gamertags_nintendo_network_id) ? $account->gamertags_nintendo_network_id : '',
        '#description' => t('If you have one, please enter your Nintendo Network ID.'),
        '#weight' => (int) variable_get('gamertags_nintendo_network_id_weight', 0),
      ),
    );
  }

  /**
   * Validation for userForm().
   */
  function userFormValidate(&$values) {
    if (($nintendo_network_id = $values['gamertags_nintendo_network_id']) && (!preg_match("/^[a-zA-Z0-9\.\-_]+$/", $nintendo_network_id) || drupal_strlen($nintendo_network_id) < 6 || drupal_strlen($nintendo_network_id) > 16)) {
      form_set_error('gamertags_nintendo_network_id', t('Nintendo Network ID field should contain numbers, letters, full stops, dashes and underscores only and be between 6 to 16 characters in length.'));
    }
  }

  public function adminUrlSettings() { return array(); }

  /**
   * Extends hook_theme().
   */
  public function theme() {
    return array(
      'arguments' => array(
        'gamertag' => NULL,
      ),
      'template' => 'platforms/nintendo/nintendo_network_id/gamertags.nintendo_network_id',
      'file' => 'platforms/nintendo/nintendo_network_id/gamertags.nintendo_network_id.inc',
    );
  }

  /**
   * Provides values for SimpleTest.
   */
  public function _testContent(&$edit, $calling_class) {
    $edit['gamertags_nintendo_network_id'] = 'test-user';
  }
}

/**
 * Preprocess function for gamertags_nintendo_network_id theme function.
 */
function gamertags_preprocess_gamertags_nintendo_network_id(&$variables) {
  drupal_add_css(drupal_get_path('module', 'gamertags') .'/platforms/nintendo/nintendo_network_id/gamertags.nintendo_network_id.css');
  $variables['alt'] = t('Nintendo Network ID');
  $variables['gamertag'] = check_plain($variables['gamertag']);
}
