<?php
/**
 * @file
 * Panels specific include file for implementing Gamertags in Panels.
 */

/**
 * Implementation of hook_ctools_content_types().
 */
function gamertags_gamertags_ctools_content_types() {
  return array(
    'single' => TRUE,
    'title' => t('Gamertags'),
    'icon' => 'icon_user.png',
    'description' => t('Gamertags from the Gamertags module.'),
    'required context' => new ctools_context_required(t('User'), 'user'),
    'category' => t('User'),
  );
}

/**
 * Callback for admin_title.
 */
function gamertags_gamertags_content_type_admin_title($subtype, $conf, $context = NULL) {
  $output = t('Gamertags');
  if ($conf['override_title'] && !empty($conf['override_title_text'])) {
    $output = filter_xss_admin($conf['override_title_text']);
  }
  return $output;
}

/**
 * Callback for admin_info.
 */
function gamertags_gamertags_content_type_admin_info($subtype, $conf, $context = NULL) {
  $block = new stdClass();
  $block->title = !empty($conf['title']) ? check_plain($conf['title']) : '';
  if (!empty($context->data->description)) {
    $block->content = check_plain($context->data->description);
  }
  return $block;
}

/**
 * Callback for edit_form so we pick up %user argument.
 */
function gamertags_gamertags_content_type_edit_form(&$form, &$form_state) {
  $form['gamertags_display_titles'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display titles'),
    '#description' => t('Display the platform title.'),
    '#default_value' => !empty($form_state['conf']['gamertags_display_titles']) ? $form_state['conf']['gamertags_display_titles'] : FALSE,
  );
  $form['gamertags_as_text'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show gamertag as text only'),
    '#description' => t('Display the user input for the gamertag, not the actual gamercard.'),
    '#default_value' => !empty($form_state['conf']['gamertags_as_text']) ? $form_state['conf']['gamertags_as_text'] : FALSE,
  );
  $form['gamertags_delimiter'] = array(
    '#type' => 'textfield',
    '#title' => t('Delimiter'),
    '#description' => t('What to use for separating the Users Gamertags.'),
    '#default_value' => !empty($form_state['conf']['gamertags_delimiter']) ? $form_state['conf']['gamertags_delimiter'] : '<br />',
    '#size' => 5,
  );
  return $form;
}

/**
 * Submit callback for edit_form, saves 'gamertags_as_text' config into $conf array.
 */
function gamertags_gamertags_content_type_edit_form_submit(&$form, &$form_state) {
  $form_state['conf']['gamertags_display_titles'] = $form_state['values']['gamertags_display_titles'];
  $form_state['conf']['gamertags_as_text'] = $form_state['values']['gamertags_as_text'];
  $form_state['conf']['gamertags_delimiter'] = $form_state['values']['gamertags_delimiter'];
}

/**
 * Callback to render our Gamertags.
 */
function gamertags_gamertags_content_type_render($subtype, $conf, $panel_args, $context) {
  $account = isset($context->data) ? drupal_clone($context->data) : NULL;
  $block = new stdClass();
  $block->title = t('Gamertags');

  if (!empty($account)) {
    $data = unserialize($account->data);
    $gamertags = array();
    $all_gamertags = gamertags_return_all();
    uasort($all_gamertags, 'element_sort');
    foreach ($all_gamertags as $class => $platform_info) {
      if (variable_get("{$class}_collect", TRUE) && !empty($data[$class])) {
        $gamertag = array();
        if ($conf['gamertags_display_titles']) {
          $gamertag[] = $platform_info['#title'];
        }
        if ($conf['gamertags_as_text']) {
          $gamertag[] = check_plain($data[$class]);
        }
        else {
          $gamertag[] = call_user_func_array(array($class, 'render'), array($account, $class));
        }
        $gamertags[] = implode(': ', $gamertag);
      }
    }
    // Be permissive to allow "<br />" tags and the like.
    $block->content = implode(filter_xss_admin($conf['gamertags_delimiter']), $gamertags);
  }
  else {
    $block->content = t('User information not available');
  }
  return $block;
}
